@@ -260,31 +260,10 @@ but the following responses are given more descriptive names automatically:
             )
         return dropdowns
 
-    @property
-    def style_plot_options(self):
-        """Simple grid layout for the selector row"""
-        return {
-            "display": "grid",
-            "align-content": "space-around",
-            "justify-content": "space-between",
-            "grid-template-columns": "2fr 1fr 1fr 1fr",
-        }
-
-    @property
-    def style_layout(self):
-        """Simple grid layout for the main elements"""
-        return {
-            "display": "grid",
-            "align-content": "space-around",
-            "justify-content": "space-between",
-            "grid-template-columns": "5fr 1fr",
-        }
-
     @property
     def plot_options_layout(self):
         """Row layout of dropdowns for plot options"""
-        return html.Div(
-            style=self.style_plot_options,
+        return wcc.FlexBox(
             children=[
                 html.Div(
                     children=html.Label(
@@ -342,21 +321,10 @@ but the following responses are given more descriptive names automatically:
     def layout(self):
         """Main layout"""
         return html.Div(
-            id=self.ids("layout"),
             children=[
-                html.Div(
-                    style=self.style_layout,
+                wcc.FlexBox(
+                    id=self.ids("layout"),
                     children=[
-                        html.Div(
-                            children=[
-                                self.plot_options_layout,
-                                html.Div(
-                                    style={"height": 400},
-                                    children=wcc.Graph(id=self.ids("graph")),
-                                ),
-                                html.Div(dash_table.DataTable(id=self.ids("table"))),
-                            ]
-                        ),
                         html.Div(
                             children=[
                                 html.P("Filters:", style={"font-weight": "bold"}),
@@ -364,11 +332,26 @@ but the following responses are given more descriptive names automatically:
                                     id=self.ids("filters"),
                                     children=self.selector_dropdowns,
                                 ),
-                            ]
+                            ],
+                        ),
+                        html.Div(
+                            children=[
+                                self.plot_options_layout,
+                                html.Div(
+                                    style={"height": 400},
+                                    children=wcc.Graph(id=self.ids("graph")),
+                                ),
+                            ],
                         ),
                     ],
-                )
-            ],
+                ),
+                dash_table.DataTable(
+                    id=self.ids("table"),
+                    columns=[
+                        {"name": i, "id": i} for i in InplaceVolumes.TABLE_STATISTICS
+                    ],
+                ),
+            ]
         )
 
     def set_callbacks(self, app):
