@@ -165,15 +165,7 @@ The types of response_filters are:
             {"id": self.ids("ensemble"), "content": ("Select the active ensemble."),},
             {"id": self.ids("responses"), "content": ("Select the active response."),},
         ]
-        if self.response_filters:
-            steps.append(
-                {
-                    "id": self.ids("filter-wrapper"),
-                    "content": (
-                        "Filter the response data before calculating correlations."
-                    ),
-                },
-            )
+
         return steps
 
     @property
@@ -227,65 +219,72 @@ The types of response_filters are:
     @property
     def filter_layout(self):
         """Layout to display selectors for response filters"""
-        if not self.response_filters:
-            return html.Div(id=self.ids("filter-wrapper"))
-        children = [html.Label("Filters")]
+        children = []
         for col_name, col_type in self.response_filters.items():
             domid = self.ids(f"filter-{col_name}")
             if col_type in ("multi", "single"):
                 values = list(self.responsedf[col_name].unique())
-                children.append(html.Label(col_name))
                 children.append(
-                    dcc.Dropdown(
-                        id=domid,
-                        options=[{"label": val, "value": val} for val in values],
-                        value=values if col_type == "multi" else values[0],
-                        multi=col_type == "multi",
-                        clearable=False,
+                    html.Div(
+                        children=[
+                            html.Label(col_name),
+                            dcc.Dropdown(
+                                id=domid,
+                                options=[
+                                    {"label": val, "value": val} for val in values
+                                ],
+                                value=values if col_type == "multi" else values[0],
+                                multi=col_type == "multi",
+                                clearable=False,
+                            ),
+                        ]
                     )
                 )
             elif col_type == "range":
-                values = self.responsedf[col_name]
-                children.append(html.Label(col_name))
-                children.append(make_range_slider(domid, values, col_name))
-        return html.Div(
-            id=self.ids("filter-wrapper"), style={"zIndex": 1000}, children=children
-        )
+                children.append(
+                    html.Div(
+                        children=[
+                            html.Label(col_name),
+                            make_range_slider(
+                                domid, self.responsedf[col_name], col_name
+                            ),
+                        ]
+                    )
+                )
+
+        return children
 
     @property
     def control_layout(self):
         """Layout to select e.g. iteration and response"""
-        return html.Div(
-            style=self.set_grid_layout("1fr 1fr 1fr 1fr"),
-            children=[
-                html.Div(
-                    [
-                        html.Label("Ensemble"),
-                        dcc.Dropdown(
-                            id=self.ids("ensemble"),
-                            options=[
-                                {"label": ens, "value": ens} for ens in self.ensembles
-                            ],
-                            clearable=False,
-                            value=self.ensembles[0],
-                        ),
-                    ]
-                ),
-                html.Div(
-                    [
-                        html.Label("Response"),
-                        dcc.Dropdown(
-                            id=self.ids("responses"),
-                            options=[
-                                {"label": ens, "value": ens} for ens in self.responses
-                            ],
-                            clearable=False,
-                            value=self.responses[0],
-                        ),
-                    ]
-                ),
-            ],
-        )
+        return [
+            html.Div(
+                [
+                    html.Label("Ensemble"),
+                    dcc.Dropdown(
+                        id=self.ids("ensemble"),
+                        options=[
+                            {"label": ens, "value": ens} for ens in self.ensembles
+                        ],
+                        clearable=False,
+                        value=self.ensembles[0],
+                    ),
+                ]
+            ),
+            html.Div(
+                [
+                    html.Label("Response"),
+                    dcc.Dropdown(
+                        id=self.ids("responses"),
+                        options=[
+                            {"label": ens, "value": ens} for ens in self.responses
+                        ],
+                        clearable=False,
+                        value=self.responses[0],
+                    ),
+                ]
+            ),
+        ]
 
     @property
     def layout(self):
@@ -293,35 +292,21 @@ The types of response_filters are:
         return html.Div(
             id=self.ids("layout"),
             children=[
-                self.control_layout,
-                html.Div(
-                    style=self.set_grid_layout("2fr 2fr 1fr")
+                wcc.FlexBox(
+                    children=self.control_layout + self.filter_layout
                     if self.response_filters
-                    else self.set_grid_layout("2fr 2fr"),
-                    children=[
-                        html.Div(
-                            children=[
-                                html.Div(
-                                    children=wcc.Graph(self.ids("correlation-graph")),
-                                ),
-                            ],
-                        ),
-                        html.Div(children=[wcc.Graph(self.ids("distribution-graph"))],),
-                        self.filter_layout if self.response_filters else html.Div(),
-                    ],
+                    else [],
                 ),
+                wcc.FlexBox(
+                    children=[
+                        wcc.Graph(self.ids("correlation-graph")),
+                        wcc.Graph(self.ids("distribution-graph")),
+                    ]
+                ),
+                dcc.Store(id=self.ids("initial-parameter")),
             ],
         )
 
-    @staticmethod
-    def set_grid_layout(columns):
-        return {
-            "display": "grid",
-            "alignContent": "space-around",
-            "justifyContent": "space-between",
-            "gridTemplateColumns": f"{columns}",
-        }
-
     @property
     def correlation_input_callbacks(self):
         """List of Inputs for correlation callback"""
@@ -339,6 +324,7 @@ The types of response_filters are:
         """List of Inputs for distribution callback"""
         callbacks = [
             Input(self.ids("correlation-graph"), "clickData"),
+            Input(self.ids("initial-parameter"), "data"),
             Input(self.ids("ensemble"), "value"),
             Input(self.ids("responses"), "value"),
         ]
@@ -359,7 +345,10 @@ The types of response_filters are:
 
     def set_callbacks(self, app):
         @app.callback(
-            Output(self.ids("correlation-graph"), "figure"),
+            [
+                Output(self.ids("correlation-graph"), "figure"),
+                Output(self.ids("initial-parameter"), "data"),
+            ],
             self.correlation_input_callbacks,
         )
         def _update_correlation_graph(ensemble, response, *filters):
@@ -389,22 +378,31 @@ The types of response_filters are:
                 corr_response = (
                     corrdf[response].dropna().drop(["REAL", response], axis=0)
                 )
-                return make_correlation_plot(
-                    corr_response, response, self.plotly_theme, self.corr_method
+
+                return (
+                    make_correlation_plot(
+                        corr_response, response, self.plotly_theme, self.corr_method
+                    ),
+                    corr_response.index[-1],
                 )
             except KeyError:
-                return {
-                    "layout": {
-                        "title": "<b>Cannot calculate correlation for given selection</b><br>"
-                        "Select a different response or filter setting."
-                    }
-                }
+                return (
+                    {
+                        "layout": {
+                            "title": "<b>Cannot calculate correlation for given selection</b><br>"
+                            "Select a different response or filter setting."
+                        }
+                    },
+                    None,
+                )
 
         @app.callback(
             Output(self.ids("distribution-graph"), "figure"),
             self.distribution_input_callbacks,
         )
-        def _update_distribution_graph(clickdata, ensemble, response, *filters):
+        def _update_distribution_graph(
+            clickdata, initial_parameter, ensemble, response, *filters
+        ):
             """Callback to update distribution graphs.
 
             1. Filters and aggregates response dataframe per realization
@@ -412,7 +410,11 @@ The types of response_filters are:
             3. Merge parameter and response dataframe
             4. Generate scatterplot and histograms
             """
-            if not clickdata:
+            if clickdata:
+                parameter = clickdata["points"][0]["y"]
+            elif initial_parameter:
+                parameter = initial_parameter
+            else:
                 raise PreventUpdate
             filteroptions = self.make_response_filters(filters)
             responsedf = filter_and_sum_responses(
@@ -423,7 +425,6 @@ The types of response_filters are:
                 aggregation=self.aggregation,
             )
             parameterdf = self.parameterdf.loc[self.parameterdf["ENSEMBLE"] == ensemble]
-            parameter = clickdata["points"][0]["y"]
             df = pd.merge(responsedf, parameterdf, on=["REAL"])[
                 ["REAL", parameter, response]
             ]
