@@ -258,58 +258,54 @@ https://github.com/equinor/webviz-subsurface-testdata/blob/master/aggregated_dat
             ]
         )
 
-    @staticmethod
-    def set_grid_layout(columns):
-        return {
-            "display": "grid",
-            "alignContent": "space-around",
-            "justifyContent": "space-between",
-            "gridTemplateColumns": f"{columns}",
-        }
-
     @property
     def layout(self):
         return html.Div(
-            id=self.ids("layout"),
-            style=self.set_grid_layout("3fr 3fr"),
             children=[
-                html.Div(
-                    [
+                wcc.FlexBox(
+                    id=self.ids("layout"),
+                    children=[
                         html.Div(
-                            style=self.set_grid_layout("1fr 2fr"),
+                            style={"flex": 2},
                             children=[
-                                self.ensemble_selector,
-                                self.smry_selector,
-                                dcc.Store(id=self.ids("date-store")),
+                                wcc.FlexBox(
+                                    children=[
+                                        self.ensemble_selector,
+                                        self.smry_selector,
+                                        dcc.Store(id=self.ids("date-store")),
+                                    ],
+                                ),
+                                html.Div(
+                                    [
+                                        html.Div(
+                                            id=self.ids("graph-wrapper"),
+                                            style={"height": "450px"},
+                                            children=wcc.Graph(
+                                                id=self.ids("graph"),
+                                                clickData={
+                                                    "points": [{"x": self.initial_date}]
+                                                },
+                                            ),
+                                        ),
+                                    ]
+                                ),
                             ],
                         ),
                         html.Div(
-                            [
-                                html.Div(
-                                    id=self.ids("graph-wrapper"),
-                                    style={"height": "450px"},
-                                    children=wcc.Graph(
-                                        id=self.ids("graph"),
-                                        clickData={
-                                            "points": [{"x": self.initial_date}]
-                                        },
-                                    ),
-                                ),
-                                DataTable(
-                                    id=self.ids("table"),
-                                    sort_action="native",
-                                    filter_action="native",
-                                    page_action="native",
-                                    page_size=10,
-                                ),
-                            ]
+                            style={"flex": 1},
+                            id=self.ids("tornado-wrapper"),
+                            children=self.tornadoplot.layout,
                         ),
-                    ]
+                    ],
                 ),
-                html.Div(
-                    id=self.ids("tornado-wrapper"), children=self.tornadoplot.layout
+                DataTable(
+                    id=self.ids("table"),
+                    sort_action="native",
+                    filter_action="native",
+                    page_action="native",
+                    page_size=10,
                 ),
-            ],
+            ]
         )
 
     def set_callbacks(self, app):
@@ -318,7 +314,7 @@ https://github.com/equinor/webviz-subsurface-testdata/blob/master/aggregated_dat
                 # Output(self.ids("date-store"), "children"),
                 Output(self.ids("table"), "data"),
                 Output(self.ids("table"), "columns"),
-                Output(self.tornadoplot.storage_id, "children"),
+                Output(self.tornadoplot.storage_id, "data"),
             ],
             [
                 Input(self.ids("ensemble"), "value"),
@@ -354,7 +350,7 @@ https://github.com/equinor/webviz-subsurface-testdata/blob/master/aggregated_dat
         @app.callback(
             Output(self.ids("graph"), "figure"),
             [
-                Input(self.tornadoplot.click_id, "children"),
+                Input(self.tornadoplot.click_id, "data"),
                 # Input(self.ids("date-store"), "children"),
                 Input(self.ids("ensemble"), "value"),
                 Input(self.ids("vector"), "value"),
@@ -364,12 +360,12 @@ https://github.com/equinor/webviz-subsurface-testdata/blob/master/aggregated_dat
         )
         def _render_tornado(tornado_click, ensemble, vector, date_click, figure):
             """Update graph with line coloring, vertical line and title"""
-            if not dash.callback_context.triggered:
+            if dash.callback_context.triggered is None:
                 raise PreventUpdate
             ctx = dash.callback_context.triggered[0]["prop_id"].split(".")[0]
 
-            # Redraw figure if ensemble/vector hanges
-            if ctx == self.ids("ensemble") or ctx == self.ids("vector"):
+            # Draw initial figure and redraw if ensemble/vector changes
+            if ctx in ["", self.ids("ensemble"), self.ids("vector")]:
                 layout = {}
                 layout.update(self.plotly_theme["layout"])
                 data = filter_ensemble(self.data, ensemble, vector)
