@@ -263,13 +263,12 @@ Default: all parameters.
 
     @property
     def layout(self):
-        return html.Div(
-            style={
-                "padding-top": 10,
-                "display": "grid",
-                "grid-template-columns": "1fr 4fr",
-            },
-            children=[self.control_div, self.plot_fig,],
+        return wcc.FlexBox(
+            style={"padding-top": 10,},
+            children=[
+                html.Div(style={"flex": "1"}, children=self.control_div),
+                html.Div(style={"flex": "4"}, children=self.plot_fig),
+            ],
         )
 
     def set_callbacks(self, app):
@@ -338,8 +337,6 @@ Default: all parameters.
             [
                 Output(self.uuid("matrix_color"), "style"),
                 Output(self.uuid("parcoords_color"), "style"),
-                Output(self.uuid("matrix_heatmap"), "style"),
-                Output(self.uuid("parcoords"), "style"),
                 Output(self.uuid("parameter_dropdown"), "style"),
                 Output(self.uuid("filter_short_checkbox"), "style"),
             ],
@@ -351,15 +348,11 @@ Default: all parameters.
                 style = (
                     {"display": "block"},
                     {"display": "none"},
-                    {"display": "block", "overflowX": "auto"},
-                    {"display": "none"},
                     {"display": "none"},
                     {"display": "block"},
                 )
             else:
                 style = (
-                    {"display": "none"},
-                    {"display": "block"},
                     {"display": "none"},
                     {"display": "block"},
                     {"display": "block"},
@@ -479,11 +472,11 @@ def render_parcoord(plot_df, params, theme, colormap, color_col, colormap_labels
                     "len": 0.3,
                 },
             },
-        ),
+        )
     else:
         data["line"].update(  # pylint: disable=expression-not-assigned
             {"colorbar": {"title": "Running time", "xanchor": "right", "x": -0.02,},},
-        ),
+        )
 
     layout = {}
     layout.update(theme["layout"])
