@@ -9,11 +9,11 @@ from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 import dash_html_components as html
 import dash_core_components as dcc
+from webviz_subsurface_components import LayeredMap
+import webviz_core_components as wcc
 from webviz_config.webviz_store import webvizstore
 from webviz_config.common_cache import CACHE
 from webviz_config import WebvizPluginABC
-import webviz_core_components as wcc
-from webviz_subsurface_components import LayeredMap
 
 from webviz_subsurface._datainput.fmu_input import get_realizations, find_surfaces
 from webviz_subsurface._datainput.surface import make_surface_layer, load_surface
@@ -371,9 +371,7 @@ and available for instant viewing.
             ]["RUNPATH"].unique()[0]
         )
 
-        return str(
-            get_path(str(runpath / "share" / "results" / "maps" / f"{data}.gri"))
-        )
+        return get_path(runpath / "share" / "results" / "maps" / f"{data}.gri")
 
     def get_ens_runpath(self, data, ensemble):
         data = make_fmu_filename(data)
@@ -381,7 +379,7 @@ and available for instant viewing.
             "RUNPATH"
         ].unique()
         return [
-            str((Path(runpath) / "share" / "results" / "maps" / f"{data}.gri"))
+            Path(runpath) / "share" / "results" / "maps" / f"{data}.gri"
             for runpath in runpaths
         ]
 
@@ -394,10 +392,10 @@ and available for instant viewing.
                 Output(self.uuid("map3-label"), "children"),
             ],
             [
-                Input(self.selector.storage_id, "children"),
+                Input(self.selector.storage_id, "data"),
                 Input(self.uuid("ensemble"), "value"),
                 Input(self.uuid("realization"), "value"),
-                Input(self.selector2.storage_id, "children"),
+                Input(self.selector2.storage_id, "data"),
                 Input(self.uuid("ensemble2"), "value"),
                 Input(self.uuid("realization2"), "value"),
                 Input(self.uuid("calculation"), "value"),
@@ -544,7 +542,7 @@ and available for instant viewing.
                     filename = f"{name}--{attr}"
                     if date is not None:
                         filename += f"--{date}"
-                    filename += f".gri"
+                    filename += ".gri"
                     filenames.append(filename)
 
         # Copy all realization files
@@ -552,14 +550,14 @@ and available for instant viewing.
             for filename in filenames:
                 path = Path(runpath) / "share" / "results" / "maps" / filename
                 if path.exists():
-                    store_functions.append((get_path, [{"path": str(path)}]))
+                    store_functions.append((get_path, [{"path": path}]))
 
         # Calculate and store statistics
         for _, ens_df in self.ens_df.groupby("ENSEMBLE"):
             runpaths = list(ens_df["RUNPATH"].unique())
             for filename in filenames:
                 paths = [
-                    str(Path(runpath) / "share" / "results" / "maps" / filename)
+                    Path(runpath) / "share" / "results" / "maps" / filename
                     for runpath in runpaths
                 ]
                 for statistic in ["Mean", "StdDev", "Min", "Max"]:
