@@ -154,8 +154,7 @@ The performance is currently slow for large grids.
         """Layout for surface section"""
         return html.Div(
             children=[
-                html.Div(
-                    style=self.set_grid_layout("1fr 1fr"),
+                wcc.FlexBox(
                     children=[
                         html.Div(
                             children=[
@@ -180,7 +179,6 @@ The performance is currently slow for large grids.
                             ]
                         ),
                         html.Div(
-                            style={"marginRight": "50px", "marginLeft": "50px"},
                             children=[
                                 dcc.RadioItems(
                                     id=self.ids("surface-type"),
@@ -225,8 +223,7 @@ The performance is currently slow for large grids.
         """Layout for color and other settings"""
         return html.Div(
             children=[
-                html.Div(
-                    style=self.set_grid_layout("3fr 2fr"),
+                wcc.FlexBox(
                     children=[
                         html.Div(
                             children=[
@@ -267,12 +264,16 @@ The performance is currently slow for large grids.
                                 ),
                             ],
                         ),
+                    ]
+                ),
+                wcc.FlexBox(
+                    children=[
                         html.Div(
                             style={
                                 "marginRight": "50px",
                                 "marginTop": "20px",
-                                "marginLeft": "50px",
                                 "marginBottom": "0px",
+                                "flex": 1,
                             },
                             children=[
                                 html.Label(
@@ -288,8 +289,11 @@ The performance is currently slow for large grids.
                                 ),
                             ],
                         ),
-                        html.Button(
-                            id=self.ids("color-range-btn"), children="Reset Range"
+                        html.Div(
+                            style={"flex": 1},
+                            children=html.Button(
+                                id=self.ids("color-range-btn"), children="Reset Range"
+                            ),
                         ),
                     ],
                 ),
@@ -304,21 +308,14 @@ The performance is currently slow for large grids.
 
     @property
     def layout(self):
-        return html.Div(
+        return wcc.FlexBox(
             id=self.ids("layout"),
-            style=self.set_grid_layout("1fr 1fr"),
-            children=[self.surface_layout, self.grid_layout],
+            children=[
+                html.Div(style={"flex": 1}, children=self.surface_layout),
+                html.Div(style={"flex": 1}, children=self.grid_layout),
+            ],
         )
 
-    @staticmethod
-    def set_grid_layout(columns):
-        return {
-            "display": "grid",
-            "alignContent": "space-around",
-            "justifyContent": "space-between",
-            "gridTemplateColumns": f"{columns}",
-        }
-
     def set_callbacks(self, app):
         @app.callback(
             Output(self.ids("map-view"), "layers"),
@@ -334,7 +331,7 @@ The performance is currently slow for large grids.
             surfacepath, surface_type, gridparameter, color_values, colorscale
         ):
 
-            surface = xtgeo.RegularSurface(str(get_path(surfacepath)))
+            surface = xtgeo.RegularSurface(get_path(surfacepath))
             hillshading = True
             min_val = None
             max_val = None
@@ -345,8 +342,8 @@ The performance is currently slow for large grids.
                 min_val = color_values[0] if color_values else None
                 max_val = color_values[1] if color_values else None
                 color = ListedColormap(colorscale) if colorscale else "viridis"
-                grid = load_grid(str(get_path(self.gridfile)))
-                gridparameter = load_grid_parameter(grid, str(get_path(gridparameter)))
+                grid = load_grid(get_path(self.gridfile))
+                gridparameter = load_grid_parameter(grid, get_path(gridparameter))
                 surface.slice_grid3d(grid, gridparameter)
                 surface.values = surface.values.filled(0)
                 if min_val is not None:
@@ -377,14 +374,14 @@ The performance is currently slow for large grids.
         def _render_fence(coords, gridparameter, surfacepath, color_values, colorscale):
             if not coords:
                 raise PreventUpdate
-            grid = load_grid(str(get_path(self.gridfile)))
-            gridparameter = load_grid_parameter(grid, str(get_path(gridparameter)))
+            grid = load_grid(get_path(self.gridfile))
+            gridparameter = load_grid_parameter(grid, get_path(gridparameter))
             fence = get_fencespec(coords)
             hmin, hmax, vmin, vmax, values = grid.get_randomline(
                 fence, gridparameter, zincrement=0.5
             )
 
-            surface = xtgeo.RegularSurface(str(get_path(surfacepath)))
+            surface = xtgeo.RegularSurface(get_path(surfacepath))
             s_arr = get_surface_fence(fence, surface)
             return make_heatmap(
                 values,
@@ -413,8 +410,8 @@ The performance is currently slow for large grids.
             [State(self.ids("gridparameter"), "value")],
         )
         def _update_color_slider(_clicks, gridparameter):
-            grid = load_grid(str(get_path(self.gridfile)))
-            gridparameter = load_grid_parameter(grid, str(get_path(gridparameter)))
+            grid = load_grid(get_path(self.gridfile))
+            gridparameter = load_grid_parameter(grid, get_path(gridparameter))
 
             minv = float(f"{gridparameter.values.min():2f}")
             maxv = float(f"{gridparameter.values.max():2f}")
